@@ -3,10 +3,6 @@ from django.http import Http404, HttpResponseRedirect
 
 from .views import page_detail
 
-import logging
-
-debug = logging.getLogger("debug")
-
 
 class PageFallbackMiddleware(object):
 
@@ -17,7 +13,6 @@ class PageFallbackMiddleware(object):
         return self.process_response(request, self.get_response(request))
 
     def process_response(self, request, response):
-        debug.info(f'middleware: {response.status_code}')
         if response.status_code != 404:
             # No need to check for a flatpage for non-404 responses.
             return response
@@ -25,8 +20,8 @@ class PageFallbackMiddleware(object):
             if request.method == "GET":
                 response = page_detail(request, url=request.path_info)
 
-                if not isinstance(response, HttpResponseRedirect):
-                    response.render()
+                # if not isinstance(response, HttpResponseRedirect):
+                #     response.render()
 
                 return response
             else:
